"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.buildPackagetson = void 0;
function buildPackagetson({ contract, frontend, tests, projectName }) {
    const result = basePackage({
        contract, frontend, tests, projectName,
    });
    return result;
}
exports.buildPackagetson = buildPackagetson;
function basePackage({ contract, frontend, tests, projectName }) {
    const hasFrontend = frontend !== 'none';
    return {
        'name': projectName,
        'version': '1.0.0',
        'license': '(MIT AND Apache-2.0)',
        'scripts': {
            ...startScript(hasFrontend),
            ...deployScript(contract),
            ...buildScript(hasFrontend),
            ...buildContractScript(contract),
            'test': 'npm run test:unit && npm run test:integration',
            ...unitTestScripts(contract),
            ...integrationTestScripts(contract, tests),
            ...npmInstallScript(contract, hasFrontend, tests),
        },
        'devDependencies': {
            'near-cli': '^3.3.0',
        },
        'dependencies': {}
    };
}
const startScript = (hasFrontend) => hasFrontend ? {
    'start': 'cd frontend && npm run dev'
} : {};
const buildScript = (hasFrontend) => hasFrontend ? {
    'build': 'npm run build:contract && npm run build:web',
    'build:web': 'cd frontend && npm run build',
} : {
    'build': 'npm run build:contract',
};
const buildContractScriptName = 'build:contract';
const buildContractScript = (contract) => {
    switch (contract) {
        case 'ts':
            return {
                [buildContractScriptName]: 'cd contract && npm run build',
            };
        case 'rs':
            return {
                [buildContractScriptName]: 'cd contract && ./build.sh',
            };
        case 'none':
            return {
                [buildContractScriptName]: 'echo "No contract to build"',
            };
    }
};
const deployScript = (contract) => {
    switch (contract) {
        case 'ts':
            return {
                'deploy': 'cd contract && npm run deploy',
            };
        case 'rs':
            return {
                'deploy': 'cd contract && ./deploy.sh',
            };
        case 'none':
            return {
                'deploy': 'echo "No contract to deploy"',
            };
    }
};
const unitTestScripts = (contract) => {
    switch (contract) {
        case 'ts':
            return { 'test:unit': 'cd contract && npm test' };
        case 'rs':
            return { 'test:unit': 'cd contract && cargo test' };
        case 'none':
            return { 'test:unit': 'echo "No contract to test"' };
    }
};
const integrationTestScripts = (contract, tests) => {
    if (contract === 'none') {
        return { 'test:integration': 'echo "No contract to test"' };
    }
    let wasm_path = '';
    switch (contract) {
        case 'ts':
            wasm_path = 'contract/build/hello_near.wasm';
            break;
        case 'rs':
            wasm_path = 'contract/target/wasm32-unknown-unknown/release/hello_near.wasm';
            break;
    }
    let run_test = '';
    switch (tests) {
        case 'ts':
            run_test = `npm test -- -- "./${wasm_path}"`;
            break;
        case 'rs':
            run_test = `cargo run --example integration-tests "../${wasm_path}"`;
            break;
    }
    return {
        'test:integration': `npm run ${buildContractScriptName} && cd integration-tests && ${run_test}`,
    };
};
const npmInstallScript = (contract, hasFrontend, tests) => {
    const frontend_install = hasFrontend ? 'cd frontend && npm install && cd ..' : 'echo no frontend';
    const test_install = (contract !== 'none' && tests === 'ts') ? 'cd integration-tests && npm install && cd ..' : 'echo no ts test';
    let contract_install = '';
    switch (contract) {
        case 'ts':
            contract_install = 'cd contract && npm install';
            break;
        case 'rs':
            contract_install = 'echo rs contract';
            break;
        case 'none':
            contract_install = 'echo no contract';
            break;
    }
    return {
        'postinstall': `${frontend_install} && ${test_install} && ${contract_install}`
    };
};
//# sourceMappingURL=package-json.js.map